# -*- coding: utf-8 -*-

from libcomxml.core import XmlModel, XmlField
from gestionatr.output.messages.base_gas import Heading
from gestionatr.output.messages.sw_a1_05 import Registerdoclist, Registerdoc


# Paso 01
class MensajeA144(XmlModel):
    _sort_order = ('mensaje', 'heading', 'a1')

    def __init__(self):
        self.doc_root = None
        self.mensaje = XmlField(
            'sctdapplication', attributes={'xmlns': 'http://localhost/sctd/A144'}
        )
        self.heading = Heading()
        self.a1 = A144()
        super(MensajeA144, self).__init__('sctdapplication', 'mensaje')


class A144(XmlModel):

    _sort_order = ('a1', 'comreferencenum', 'sourcetype', 'firstname',
                   'lastname', 'secondname', 'cups', 'operationtype',
                   'description', 'operationnum', 'prefixtel1', 'telephone1',
                   'prefixtel2', 'telephone2', 'reqdate', 'reqhour', 'readingdate',
                   'readingvalue', 'extrainfo', 'registerdoclist')

    def __init__(self):
        self.a1 = XmlField('a1')
        self.comreferencenum = XmlField('comreferencenum')
        self.sourcetype = XmlField('sourcetype')
        self.firstname = XmlField('firstname')
        self.lastname = XmlField('lastname')
        self.secondname = XmlField('secondname')
        self.cups = XmlField('cups')
        self.operationtype = XmlField('operationtype')
        self.description = XmlField('description')
        self.operationnum = XmlField('operationnum')
        self.prefixtel1 = XmlField('prefixtel1')
        self.telephone1 = XmlField('telephone1')
        self.prefixtel2 = XmlField('prefixtel2')
        self.telephone2 = XmlField('telephone2')
        self.reqdate = XmlField('reqdate')
        self.reqhour = XmlField('reqhour')
        self.readingdate = XmlField('readingdate')
        self.readingvalue = XmlField('readingvalue')
        self.extrainfo = XmlField('extrainfo')
        self.registerdoclist = Registerdoclist()
        super(A144, self).__init__('a1', 'a1')




# -*- coding: utf-8 -*-

"""Helper functions for libComXml
"""

CODIS_REFACT = {'RT42011': '40',
                'RT12012': '41',
                'RM42012': '42'}

CODIS_REG_REFACT = {'RGT42011': '40',
                    'RGT12012': '41',
                    'RGM42012': '42'}

PERIODES_AGRUPATS = [('P1', 'P4'), ('P2', 'P5'), ('P3', 'P6')]


def codi_refact(producte):
    """Retorna el codi ocsum de refacturació

    :param producte: nom del producte
    """
    return CODIS_REFACT.get(producte, False)


def nom_refact(producte):
    """Retorna el nom del producte

    :param producte: codi ocsum del producte
    """
    ref = dict(((v, k) for k, v in CODIS_REFACT.items()))
    return ref.get(producte, False)


def nom_reg_refact(producte):
    """Retorna el nom del producte

    :param producte: codi ocsum del producte
    """
    ref = dict(((v, k) for k, v in CODIS_REG_REFACT.items()))
    return ref.get(producte, False)


def parse_totals_refact(cadena):
    """Retorna els totals de les línies de refacturacio"""
    totals = []
    for i, x in enumerate(cadena.split(' ')):
        if i in (4, 7):
            totals.append(float(x))
    return totals[0], totals[1]


def extreu_periode(name):
    """Extreu el nom del període del name de la lectura
    """
    if '(' not in name:
        return name
    return name.split('(')[-1].split(')')[0]


def codi_periode(codi_dh, periode):
    """Retorna el codi OCSUM del periode segons
       http://172.26.0.42:2500/wiki/show/Codificacio_Periodes_OCSUM
       Taula 42 del document d'OCSUM:
       OCSUM - E - Tablas de códigos 2012.05.23.doc

    :param codi_dh: codi dh de la tarifa
    :param periode: nom del periode en format Px on x = {1...6}
    """

    if codi_dh == '1':
        return '10'
    else:
        return '%s%s' % (codi_dh, periode[-1])


def codi_dh(tarifa, nlectures=6):
    """Retorna el codi ocsum de discriminació horaria
       Taules 35 i 107 del document d'OCSUM:
       OCSUM - E - Tablas de códigos 2012.05.23.doc

    :param tarifa: codi de la tarifa
    :param nlectures: nombre de lectures
    """

    if tarifa in ('001', '005'):
        return '1'
    elif tarifa in ('004', '006'):
        return '2'
    elif tarifa in ('003', '012', '013', '014', '015', '016', '017'):
        return '6'
    elif tarifa == '011':
        if nlectures in (6, 5):
            return '6'
        else:
            return '3'
    elif tarifa in ('007', '008'):
        return '8'
    elif tarifa == '018':
        return '9'
    elif tarifa in ('019', '020', '021', '022', '023', '024', '025'):
        return 'A'



# -*- coding: utf-8 -*-
from A1_38 import *




class A1_42(A1_38):

    steps = []

    # Datos paso a242
    # ja tenim de les herències

    # Datos paso a2542
    # ja tenim de les herències

    # Datos paso a442
    # ja tenim de les herències

    # Datos paso a342
    # ja tenim de les herències

    # Datos paso a2s42
    # ja tenim de les herències

    # Datos paso a3s42
    # ja tenim de les herències

    # Datos paso a4s42
    # ja tenim de les herències


class product(product):

    @property
    def reqtype(self):
        tree = 'reqtype'
        data = get_rec_attr(self.obj, tree, False)
        if data is not None and data is not False:
            return data.text
        else:
            return False
